==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/aspect/AspectEntity.java <==
package io.intino.sumus.graph.aspect;

import io.intino.sumus.graph.*;


public class AspectEntity extends io.intino.tara.magritte.Layer {


	protected io.intino.sumus.graph.Entity _entity;

	public AspectEntity(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList() {
		return (java.util.List<io.intino.sumus.graph.Entity>) _entity.entityList();
	}

	public io.intino.sumus.graph.Entity entityList(int index) {
		return _entity.entityList().get(index);
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());

		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();

		return map;
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	@Override
	protected void sync$(io.intino.tara.magritte.Layer layer) {
		super.sync$(layer);
	    if (layer instanceof io.intino.sumus.graph.Entity) _entity = (io.intino.sumus.graph.Entity) layer;

	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Entity entity() {
		    io.intino.sumus.graph.Entity newElement = core$().graph().concept(io.intino.sumus.graph.Entity.class).createNode(name, core$()).as(io.intino.sumus.graph.Entity.class);

		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.sumus.graph.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-6.4.5-sources.jar: io/intino/sumus/graph/aspect/AspectEntity.java <==
package io.intino.sumus.graph.aspect;

import io.intino.sumus.graph.*;


public class AspectEntity extends io.intino.tara.magritte.Layer {

	protected java.util.List<io.intino.sumus.graph.Entity> entityList = new java.util.ArrayList<>();
	protected io.intino.sumus.graph.Entity _entity;

	public AspectEntity(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList() {
		return java.util.Collections.unmodifiableList(entityList);
	}

	public io.intino.sumus.graph.Entity entity(int index) {
		return entityList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList(java.util.function.Predicate<io.intino.sumus.graph.Entity> predicate) {
		return entityList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(entityList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Entity")) this.entityList.add(node.as(io.intino.sumus.graph.Entity.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Entity")) this.entityList.remove(node.as(io.intino.sumus.graph.Entity.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	@Override
	protected void sync$(io.intino.tara.magritte.Layer layer) {
		super.sync$(layer);
	    if (layer instanceof io.intino.sumus.graph.Entity) _entity = (io.intino.sumus.graph.Entity) layer;

	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Entity entity() {
		    io.intino.sumus.graph.Entity newElement = core$().graph().concept(io.intino.sumus.graph.Entity.class).createNode(name, core$()).as(io.intino.sumus.graph.Entity.class);

		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.sumus.graph.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
